@@ -20,13 +20,13 @@ def upload_to_S3(region):
 def write_to_dynamo_db(region,requestID):
     client=boto3.client('dynamodb',region_name=region)
     item_dict={
-        'status': {'S':'COMPLETED'},
-        'data_name': {'S':object_name},
-        'timestamp': {'S':str(datetime.datetime.now())}
+        'status':'COMPLETED',
+        'data_name':object_name,
+        'timestamp': str(datetime.datetime.now())
     }
     
     client.update_item(TableName='architectureDB',
     Key={
         'requestID':{'S':requestID}
     },
-    Item=item_dict)
+    AttributeUpdates=item_dict)
